#!/usr/bin/perl -w

# ldapgdmfaces.pl - fetch pictures from LDAP for use in gdm
#
# Copyright (C) 2005 Arthur de Jong.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 3. The name of the author may not be used to endorse or promote
#    products derived from this software without specific prior
#    written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
# GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
# IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


# start of configuration section

# name of ldap server
$ldapserver='ldap';

# base of LDAP directory
$ldapbase='ou=people,dc=example,dc=com';

# where should we store face files
$photobase='/usr/share/faces';

# end of configuration section


# requires libnet-ldap-perl
use Net::LDAP;

# connect to the ldap server
$ldap=Net::LDAP->new($ldapserver) or die "$@";

# anonymous bind
$ldap->bind(version => 3);

# search for all users with photo's
$result=$ldap->search(base   => $ldapbase,
                      scope  => 'sub',
                      filter => '(&(objectclass=PosixAccount)(jpegPhoto=*))',
                      attrs  => [ 'dn','uid','jpegPhoto' ] );

# loop over results
my $entr;
foreach $entr ( $result->entries ) {
  my $uid=$entr->get_value('uid');
  # limited sanity check in uid part
  next unless ($uid =~ /^[a-zA-Z0-9_-]+$/);
  # write photo
  open(PHOTO,'>'.$photobase.'/'.$uid);
  print PHOTO $entr->get_value('jpegPhoto');
  close(PHOTO);
}
